r4619 - in trunk: . lib src/edu/ucsb/nceas/metacat/util

daigle at ecoinformatics.org daigle at ecoinformatics.org
Mon Nov 24 11:51:33 PST 2008


Author: daigle
Date: 2008-11-24 11:51:33 -0800 (Mon, 24 Nov 2008)
New Revision: 4619

Modified:
   trunk/build.properties
   trunk/build.xml
   trunk/lib/metacat.properties
   trunk/src/edu/ucsb/nceas/metacat/util/SystemUtil.java
Log:
Add release info property to provide a brief description of the release (release candidate info mostly)

Modified: trunk/build.properties
===================================================================
--- trunk/build.properties	2008-11-24 19:51:10 UTC (rev 4618)
+++ trunk/build.properties	2008-11-24 19:51:33 UTC (rev 4619)
@@ -1,8 +1,12 @@
 # Ant build properties files for the metacat build
 
-#Version of this build
+#Version of this build.  This needs to be a dotted numeric version.  For
+#instance 1.9.1 is okay.  1.9.1_rc1 is not.
 metacat.version=1.9.0
 
+#This is for display purposes.  leave it blank for final production release.
+metacat.releaseInfo=Release Candidate 1
+
 # Tomcat dev deployment directory
 # build.tomcat.dir=/usr/local/tomcat
 build.tomcat.dir=/usr/local/devtools/jakarta-tomcat

Modified: trunk/build.xml
===================================================================
--- trunk/build.xml	2008-11-24 19:51:10 UTC (rev 4618)
+++ trunk/build.xml	2008-11-24 19:51:33 UTC (rev 4619)
@@ -141,6 +141,7 @@
       <filter token="adminname"            value="${adminname}"/>
       <filter token="recipient"            value="${recipient}"/>
    	  <filter token="metacatVersion"       value="${metacat.version}"/>
+ 	  <filter token="metacatReleaseInfo"       value="${metacat.releaseInfo}"/>
 
       <filter token="docrooturl"           value="./" />
       <filter token="mcuser"               value="${mcuser}"/>

Modified: trunk/lib/metacat.properties
===================================================================
--- trunk/lib/metacat.properties	2008-11-24 19:51:10 UTC (rev 4618)
+++ trunk/lib/metacat.properties	2008-11-24 19:51:33 UTC (rev 4619)
@@ -23,7 +23,7 @@
 
 ## one of the few places where we use ANT tokens
 application.metacatVersion=@metacatVersion@
-## This is autodiscovered and populated by the config utility
+application.metacatReleaseInfo=@metacatReleaseInfo@
 
 application.deployDir=
 ## This is autodiscovered and populated by the config utility

Modified: trunk/src/edu/ucsb/nceas/metacat/util/SystemUtil.java
===================================================================
--- trunk/src/edu/ucsb/nceas/metacat/util/SystemUtil.java	2008-11-24 19:51:10 UTC (rev 4618)
+++ trunk/src/edu/ucsb/nceas/metacat/util/SystemUtil.java	2008-11-24 19:51:33 UTC (rev 4619)
@@ -206,7 +206,9 @@
 	
 	/**
 	 * Get the metacat version by getting the string representation from
 	 * metacat.properties and instantiating a MetaCatVersion object
 	 * 
 	 * @return a MetaCatVersion object holding metacat version information
 	 */
@@ -215,6 +217,19 @@
 			PropertyService.getProperty("application.metacatVersion");
 		return new MetaCatVersion(metacatVersionString);
 	}
+	
+	/**
+	 * Gets a string that holds some description about the release. Typically this is 
+	 * used during release candidates for display purposes and might hold something
+	 * like "Release Candidate 1".  Normally it is empty for final production release.
+	 * The info is set in build.properties and then populated into metacat.properties
+	 * at build time using Ant token replacement.
+	 * 
+	 * @return a MetaCatVersion object holding metacat version information
+	 */
+	public static String getMetacatReleaseInfo() throws PropertyNotFoundException {
+		return PropertyService.getProperty("application.metacatReleaseInfo");
+	}
 
 	/**
 	 * Get the context directory. This is made up of the deployment directory + file
@@ -206,7 +206,9 @@
 	/**
 	 * Get the metacat version by getting the string representation from
-	 * metacat.properties and instantiating a MetaCatVersion object
+	 * metacat.properties and instantiating a MetaCatVersion object.
+	 * The info is set in build.properties and then populated into metacat.properties
+	 * at build time using Ant token replacement.
 	 * 
 	 * @return a MetaCatVersion object holding metacat version information



More information about the Metacat-cvs mailing list